"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postOne = void 0;
const swagger_1 = require("@nestjs/swagger");
const class_transformer_1 = require("class-transformer");
const utils_1 = require("../utils");
const index_1 = require("./index");
function postOne(controller, entity, binding, config) {
    const entityName = entity instanceof Function ? entity.name : entity.options.name;
    const descriptor = Reflect.getOwnPropertyDescriptor(controller.prototype, binding.name);
    if (!descriptor) {
        return;
    }
    const columOptions = (0, utils_1.getColumOptions)(entity);
    const fakeObject = Object.keys(columOptions).reduce((acum, item) => {
        acum[item] = '';
        return acum;
    }, {});
    const currentField = Object.keys((0, class_transformer_1.plainToClass)(entity, fakeObject)).map((i) => i);
    (0, swagger_1.ApiBody)({
        description: `Json api schema for new "${entityName}" item`,
        schema: {
            type: 'object',
            properties: (0, utils_1.jsonSchemaBody)(entity, currentField),
            required: ['data'],
        },
        required: true,
    })(controller.prototype, binding.name, descriptor);
    (0, swagger_1.ApiResponse)({
        status: 201,
        schema: Object.assign({}, (0, utils_1.jsonSchemaResponse)(entity, currentField)),
        description: `Item of resource "${entityName}" has been created`,
    })(controller.prototype, binding.name, descriptor);
    (0, swagger_1.ApiResponse)({
        status: 422,
        description: 'Unprocessable data',
        schema: index_1.errorSchema,
    })(controller.prototype, binding.name, descriptor);
    (0, swagger_1.ApiOperation)({
        summary: `Create item of resource "${entityName}"`,
        operationId: `${controller.name}_${binding.name}`,
    })(controller.prototype, binding.name, descriptor);
}
exports.postOne = postOne;
//# sourceMappingURL=post-one.js.map